@@ -101,7 +101,7 @@ class DeviceManager:
 
         :returns: A list of integers representing the partition numbers"""
         partition_table_proc = subprocess.Popen(
-            ["parted", "-s", self.device, "p"],
+            ["parted", "-s", self.device, "print"],
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT)
         output, error = partition_table_proc.communicate()
@@ -239,26 +239,21 @@ class DeviceManager:
                                         supported partition type."""
 
         process = subprocess.Popen(
-            ["parted", "-s", self.device, "print"], stdout=subprocess.PIPE)
+            ["partprobe", "-s", "-d", self.device], stdout=subprocess.PIPE)
         output, error = process.communicate()
         exit_code = process.returncode
         if exit_code != 0:
             raise weresync.exception.DeviceError(self.device,
                                                  "Non-zero exit code",
                                                  str(output, "utf-8"))
-        result = str(output, "utf-8").split("\n")
-        for line in result:
-            line = line.split(":")
-            if line[0] == "Partition Table":
-                table_type = line[1].strip()
-                break
-
-        if table_type not in SUPPORTED_PARTITION_TABLE_TYPES:
-            raise weresync.exception.UnsupportedDeviceError(
-                "Partition table"
-                "type {0} not supported by WereSync.".format(table_type))
+        result = str(output, "utf-8")
+        for table_type in SUPPORTED_PARTITION_TABLE_TYPES:
+            if table_type in result:
+                return table_type
         else:
-            return table_type
+            raise weresync.exception.UnsupportedDeviceError(
+                "Partition table "
+                "type of {0} not supported by WereSync.".format(self.device))
 
     def get_drive_size(self):
         """Returns the maximum size of the drive, in sectors."""
@@ -676,7 +671,6 @@ class LVMDeviceManager(DeviceManager):
             x.strip().split(":") for x in str(output, "utf-8").split("\n")
             if x.strip() != ""
         ]
-        LOGGER.debug(str(lines))
         return [x[0] for x in lines[1:] if x[1] == self.name]
 
     def get_partition_table_type(self):
@@ -761,9 +755,11 @@ class LVMDeviceManager(DeviceManager):
         self.device = self.device.replace("-", "--")
         old_mask = self.part_mask
         self.part_mask = "/dev/mapper/{0}-{1}"
-        result = super()._get_general_info(partition_num)
-        self.device = old_name
-        self.part_mask = old_mask
+        try:
+            result = super()._get_general_info(partition_num)
+        finally:
+            self.device = old_name
+            self.part_mask = old_mask
         return result
 
     # TODO make this work if needed with LVM drives
@@ -872,6 +868,8 @@ class DeviceCopier:
                 uuids[source_part_uuid] = self.target.get_part_uuid(i)
 
             if self.lvm_source is not None:
+                print("LVM Source is: " + self.lvm_source.device)
+                print("meaningless space")
                 source_vg = parse.parse("/dev/{0}", self.lvm_source.device)[0]
                 target_vg = parse.parse("/dev/{0}", self.lvm_target.device)[0]
                 source_name = source_vg.replace("-", "--")
@@ -1406,7 +1404,7 @@ class DeviceCopier:
                                     output, error = proc.communicate()
                                     if proc.returncode == 2:
                                         raise weresync.exception.DeviceError(
-                                            self.soruce.device,
+                                            self.source.device,
                                             "Could not find block name of "
                                             "device with id: {0}".format(
                                                 identifier),
